@@ -82,7 +82,10 @@
             # convert AutoCommit values to magic ones to let DBI
             # know that the driver has 'handled' the AutoCommit attribute
             $value = ($value) ? -901 : -900;
-	}
+	} elsif ($attrib eq 'nullp_set_err') {
+           # a fake attribute to produce a test case where STORE issues a warning
+           $dbh->set_err($value, $value);
+        }
 	return $dbh->SUPER::STORE($attrib, $value);
     }
 
