@@ -1,6 +1,6 @@
 package DBI::DBD::Metadata;
 
-# $Id: Metadata.pm,v 1.5 2004/02/01 11:16:16 timbo Exp $
+# $Id: Metadata.pm 14213 2010-06-30 19:29:18Z Martin $
 #
 # Copyright (c) 1997-2003 Jonathan Leffler, Jochen Wiedmann,
 # Steffen Goeldner and Tim Bunce
@@ -18,10 +18,9 @@ use DBI::Const::GetInfoType qw(%GetInfoType);
 @ISA = qw(Exporter);
 @EXPORT = qw(write_getinfo_pm write_typeinfo_pm);
 
-use strict;
+$VERSION = "2.014214";
 
-my
-$VERSION = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
+use strict;
 
 =head1 NAME
 
@@ -33,13 +32,13 @@ The idea is to extract metadata information from a good quality
 ODBC driver and use it to generate code and data to use in your own
 DBI driver for the same database.
 
-For generating code to support the get_info method:
+To generate code to support the get_info method:
 
   perl -MDBI::DBD::Metadata -e "write_getinfo_pm('dbi:ODBC:dsn-name','user','pass','Driver')"
 
   perl -MDBI::DBD::Metadata -e write_getinfo_pm dbi:ODBC:foo_db username password Driver
 
-For generating code to support the type_info method:
+To generate code to support the type_info method:
 
   perl -MDBI::DBD::Metadata -e "write_typeinfo_pm('dbi:ODBC:dsn-name','user','pass','Driver')"
 
@@ -48,7 +47,7 @@ For generating code to support the type_info method:
 Where C<dbi:ODBC:dsn-name> is the connection to use to extract the
 data, and C<Driver> is the name of the driver you want the code
 generated for (the driver name gets embedded into the output in
-many places).
+numerous places).
 
 =head1 Generating a GetInfo package for a driver
 
@@ -58,13 +57,13 @@ DBD::Driver::GetInfo package on standard output.
 This method generates a DBD::Driver::GetInfo package from the data
 source you specified in the parameter list or in the environment
 variable DBI_DSN.
-DBD::Driver::GetInfo should help a DBD author implementing the DBI
+DBD::Driver::GetInfo should help a DBD author implement the DBI
 get_info() method.
-Because you are just creating this package, it's very unlikely that
+Because you are just creating this package, it is very unlikely that
 DBD::Driver already provides a good implementation for get_info().
 Thus you will probably connect via DBD::ODBC.
 
-Once you are sure that it is producing semi-sane data, you would
+Once you are sure that it is producing reasonably sane data, you should
 typically redirect the standard output to lib/DBD/Driver/GetInfo.pm, and
 then hand edit the result.
 Do not forget to update your Makefile.PL and MANIFEST to include this as
@@ -79,7 +78,7 @@ The generator assumes that most values are static and places these
 values directly in the %info hash.
 A few examples show the use of CODE references and the implementation
 via subroutines.
-It is very likely that you have to write additional subroutines for
+It is very likely that you will have to write additional subroutines for
 values depending on the session state or server version, e.g.
 SQL_DBMS_VER.
 
@@ -186,6 +185,9 @@ PERL
         elsif ($key eq 'SQL_KEYWORDS') {
             $val = ($kw_map) ? '\&sql_keywords' : 'undef';
         }
+        elsif ($key eq 'SQL_DRIVER_NAME') {
+            $val = "\$INC{'DBD/$driver.pm'}";
+        }
         elsif ($key eq 'SQL_DRIVER_VER') {
             $val = '$sql_driver_ver';
         }
@@ -224,7 +226,7 @@ where the odbc_dsn is a DSN for one of the driver's databases.
 The user and pass parameters are the other optional connection
 parameters that will be provided to the DBI connect method.
 
-Once you are sure that it is producing semi-sane data, you would
+Once you are sure that it is producing reasonably sane data, you should
 typically redirect the standard output to lib/DBD/Driver/TypeInfo.pm,
 and then hand edit the result if necessary.
 Do not forget to update your Makefile.PL and MANIFEST to include this as
@@ -241,7 +243,7 @@ A possible implementation of DBD::Driver::type_info_all() may look like:
   sub type_info_all {
     my ($dbh) = @_;
     require DBD::Driver::TypeInfo;
-    return $DBD::Driver::TypeInfo::type_info_all;
+    return [ @$DBD::Driver::TypeInfo::type_info_all ];
   }
 
 Please replace Driver (or "<foo>") with the name of your driver.
@@ -324,7 +326,7 @@ package DBD::${driver}::db;         # This line can be removed once transferred.
     {
         my (\$dbh) = \@_;
         require DBD::${driver}::TypeInfo;
-        return \$DBD::${driver}::TypeInfo::type_info_all;
+        return [ \@\$DBD::${driver}::TypeInfo::type_info_all ];
     }
 
 # Transfer this to lib/DBD/${driver}/TypeInfo.pm.
@@ -340,7 +342,7 @@ package DBD::${driver}::TypeInfo;
     require DynaLoader;
     \@ISA = qw(Exporter DynaLoader);
     \@EXPORT = qw(type_info_all);
-    use DBI (:sql_types);
+    use DBI qw(:sql_types);
 
 PERL
 
@@ -409,7 +411,7 @@ PERL
 
     my $h = $dbh->type_info_all;
     my @tia = @$h;
-    my %odbc_map = %{$tia[0]};
+    my %odbc_map = map { uc $_ => $tia[0]->{$_} } keys %{$tia[0]};
     shift @tia;     # Remove the mapping reference.
     my $numtyp = $#tia;
 
@@ -484,7 +486,7 @@ __END__
 
 Jonathan Leffler <jleffler@us.ibm.com> (previously <jleffler@informix.com>),
 Jochen Wiedmann <joe@ispsoft.de>,
-Steffen Goeldner <s.goeldner@eurodata.de>,
+Steffen Goeldner <sgoeldner@cpan.org>,
 and Tim Bunce <dbi-users@perl.org>.
 
 =cut
