@@ -36,7 +36,7 @@ This module can also be used to roll your own profile analysis:
   $prof->match(key1 => qr/^SELECT/i);
 
   # produce a formatted report with the given number of items
-  $report = $prof->report(number => 10); 
+  $report = $prof->report(number => 10);
 
   # clone the profile data set
   $clone = $prof->clone();
@@ -56,7 +56,7 @@ This module can also be used to roll your own profile analysis:
 =head1 DESCRIPTION
 
 This module offers the ability to read, manipulate and format
-DBI::ProfileDumper profile data.  
+DBI::ProfileDumper profile data.
 
 Conceptually, a profile consists of a series of records, or nodes,
 each of each has a set of statistics and set of keys.  Each record
@@ -69,8 +69,7 @@ The following methods are supported by DBI::ProfileData objects.
 
 =cut
 
-
-our $VERSION = sprintf("2.%06d", q$Revision: 9632 $ =~ /(\d+)/o);
+our $VERSION = "2.010008";
 
 use Carp qw(croak);
 use Symbol;
@@ -88,13 +87,19 @@ sub FIRST_AT  () { 5 };
 sub LAST_AT   () { 6 };
 sub PATH      () { 7 };
 
+
+my $HAS_FLOCK = (defined $ENV{DBI_PROFILE_FLOCK})
+    ? $ENV{DBI_PROFILE_FLOCK}
+    : do { local $@; eval { flock STDOUT, 0; 1 } };
+
+
 =head2 $prof = DBI::ProfileData->new(File => "dbi.prof")
 
 =head2 $prof = DBI::ProfileData->new(File => "dbi.prof", Filter => sub { ... })
 
 =head2 $prof = DBI::ProfileData->new(Files => [ "dbi.prof.1", "dbi.prof.2" ])
 
-Creates a a new DBI::ProfileData object.  Takes either a single file
+Creates a new DBI::ProfileData object.  Takes either a single file
 through the File option or a list of Files in an array ref.  If
 multiple files are specified then the header data from the first file
 is used.
@@ -157,10 +162,11 @@ data for many different SQL statement. See L<DBI::Profile>.
 
 sub new {
     my $pkg = shift;
-    my $self = {                
+    my $self = {
                 Files        => [ "dbi.prof" ],
 		Filter       => undef,
                 DeleteFiles  => 0,
+                LockFile     => $HAS_FLOCK,
                 _header      => {},
                 _nodes       => [],
                 _node_lookup => {},
@@ -168,7 +174,7 @@ sub new {
                 @_
                };
     bless $self, $pkg;
-    
+
     # File (singular) overrides Files (plural)
     $self->{Files} = [ $self->{File} ] if exists $self->{File};
 
@@ -182,16 +188,22 @@ sub _read_files {
     my $files  = $self->{Files};
     my $read_header = 0;
     my @files_to_delete;
-  
+
     my $fh = gensym;
     foreach (@$files) {
         my $filename = $_;
 
         if ($self->{DeleteFiles}) {
             my $newfilename = $filename . ".deleteme";
+	    if ($^O eq 'VMS') {
+		# VMS default filesystem can only have one period
+		$newfilename = $filename . 'deleteme';
+	    }
             # will clobber an existing $newfilename
             rename($filename, $newfilename)
                 or croak "Can't rename($filename, $newfilename): $!";
+	    # On a versioned filesystem we want old versions to be removed
+	    1 while (unlink $filename);
             $filename = $newfilename;
         }
 
@@ -199,8 +211,8 @@ sub _read_files {
           or croak("Unable to read profile file '$filename': $!");
 
         # lock the file in case it's still being written to
-        # (we'll be foced to wait till the write is complete)
-        flock($fh, LOCK_SH);
+        # (we'll be forced to wait till the write is complete)
+        flock($fh, LOCK_SH) if $self->{LockFile};
 
         if (-s $fh) {   # not empty
             $self->_read_header($fh, $filename, $read_header ? 0 : 1);
@@ -208,12 +220,18 @@ sub _read_files {
             $self->_read_body($fh, $filename);
         }
         close($fh); # and release lock
-        
+
         push @files_to_delete, $filename
             if $self->{DeleteFiles};
     }
-    unlink $_ or warn "Can't delete '$_': $!" for @files_to_delete;
-    
+    for (@files_to_delete){
+	# for versioned file systems
+	1 while (unlink $_);
+	if(-e $_){
+	    warn "Can't delete '$_': $!";
+	}
+    }
+
     # discard node_lookup now that all files are read
     delete $self->{_node_lookup};
 }
@@ -229,17 +247,28 @@ sub _read_header {
     $self->{_profiler} = $first if $keep;
 
     # collect variables from the header
+    local $_;
     while (<$fh>) {
         chomp;
         last unless length $_;
         /^(\S+)\s*=\s*(.*)/
           or croak("Syntax error in header in $filename line $.: $_");
         # XXX should compare new with existing (from previous file)
-        # and warn if they differ (diferent program or path)
-        $self->{_header}{$1} = $2 if $keep;
+        # and warn if they differ (different program or path)
+        $self->{_header}{$1} = unescape_key($2) if $keep;
     }
 }
 
+
+sub unescape_key {  # inverse of escape_key() in DBI::ProfileDumper
+    local $_ = shift;
+    s/(?<!\\)\\n/\n/g; # expand \n, unless it's a \\n
+    s/(?<!\\)\\r/\r/g; # expand \r, unless it's a \\r
+    s/\\\\/\\/g;       # \\ to \
+    return $_;
+}
+
+
 # reads the body of the profile data
 sub _read_body {
     my ($self, $fh, $filename) = @_;
@@ -249,20 +278,16 @@ sub _read_body {
 
     # build up node array
     my @path = ("");
-    my (@data, $index, $key, $path_key);
+    my (@data, $path_key);
+    local $_;
     while (<$fh>) {
         chomp;
         if (/^\+\s+(\d+)\s?(.*)/) {
             # it's a key
-            ($key, $index) = ($2, $1 - 1);
-
-            # unmangle key
-            $key =~ s/(?<!\\)\\n/\n/g; # expand \n, unless it's a \\n
-            $key =~ s/(?<!\\)\\r/\r/g; # expand \r, unless it's a \\r
-            $key =~ s/\\\\/\\/g;       # \\ to \
+            my ($key, $index) = ($2, $1 - 1);
 
             $#path = $index;      # truncate path to new length
-            $path[$index] = $key; # place new key at end
+            $path[$index] = unescape_key($key); # place new key at end
 
         }
 	elsif (s/^=\s+//) {
@@ -424,22 +449,22 @@ the dbiprof frontend.
         my $self = shift;
         my $nodes = $self->{_nodes};
         my %opt = @_;
-        
+
         croak("Missing required field option.") unless $opt{field};
 
         my $index = $FIELDS{$opt{field}};
-        
+
         croak("Unrecognized sort field '$opt{field}'.")
           unless defined $index;
 
         # sort over index
         if ($opt{reverse}) {
-            @$nodes = sort { 
-                $a->[$index] <=> $b->[$index] 
+            @$nodes = sort {
+                $a->[$index] <=> $b->[$index]
             } @$nodes;
         } else {
-            @$nodes = sort { 
-                $b->[$index] <=> $a->[$index] 
+            @$nodes = sort {
+                $b->[$index] <=> $a->[$index]
             } @$nodes;
         }
 
@@ -483,16 +508,16 @@ sub exclude {
     if (UNIVERSAL::isa($val,"Regexp")) {
         # regex match
         @$nodes = grep {
-            $#$_ < $index or $_->[$index] !~ /$val/ 
+            $#$_ < $index or $_->[$index] !~ /$val/
         } @$nodes;
     } else {
         if ($opt{case_sensitive}) {
-            @$nodes = grep { 
+            @$nodes = grep {
                 $#$_ < $index or $_->[$index] ne $val;
             } @$nodes;
         } else {
             $val = lc $val;
-            @$nodes = grep { 
+            @$nodes = grep {
                 $#$_ < $index or lc($_->[$index]) ne $val;
             } @$nodes;
         }
@@ -534,16 +559,16 @@ sub match {
     if (UNIVERSAL::isa($val,"Regexp")) {
         # regex match
         @$nodes = grep {
-            $#$_ >= $index and $_->[$index] =~ /$val/ 
+            $#$_ >= $index and $_->[$index] =~ /$val/
         } @$nodes;
     } else {
         if ($opt{case_sensitive}) {
-            @$nodes = grep { 
+            @$nodes = grep {
                 $#$_ >= $index and $_->[$index] eq $val;
             } @$nodes;
         } else {
             $val = lc $val;
-            @$nodes = grep { 
+            @$nodes = grep {
                 $#$_ >= $index and lc($_->[$index]) eq $val;
             } @$nodes;
         }
@@ -590,12 +615,12 @@ Formats a single node into a human-readable block of text.
 sub format {
     my ($self, $node) = @_;
     my $format;
-    
+
     # setup keys
     my $keys = "";
     for (my $i = PATH; $i <= $#$node; $i++) {
         my $key = $node->[$i];
-        
+
         # remove leading and trailing space
         $key =~ s/^\s+//;
         $key =~ s/\s+$//;
@@ -618,7 +643,7 @@ sub format {
   Shortest Time : %3.6f seconds
   Average Time  : %3.6f seconds
 END
-        return sprintf($format, @{$node}[COUNT,TOTAL,LONGEST,SHORTEST], 
+        return sprintf($format, @{$node}[COUNT,TOTAL,LONGEST,SHORTEST],
                        $node->[TOTAL] / $node->[COUNT]) . $keys;
     } else {
         $format = <<END;
@@ -649,7 +674,7 @@ sub report {
 
     my $report = $self->_report_header($opt{number});
     for (0 .. $opt{number} - 1) {
-        $report .= sprintf("#" x 5  . "[ %d ]". "#" x 59 . "\n", 
+        $report .= sprintf("#" x 5  . "[ %d ]". "#" x 59 . "\n",
                            $_ + 1);
         $report .= $self->format($nodes->[$_]);
         $report .= "\n";
@@ -685,7 +710,7 @@ END
     $header .= sprintf(<<END, $node_count, $number, $self->{_sort}, $count, $time);
   Total Records : %d (showing %d, sorted by %s)
   Total Count   : %d
-  Total Runtime : %3.6f seconds  
+  Total Runtime : %3.6f seconds
 
 END
 
