@@ -28,7 +28,7 @@ require utf8;
 } unless defined &utf8::is_utf8;
 
 $DBI::PurePerl = $ENV{DBI_PUREPERL} || 1;
-$DBI::PurePerl::VERSION = sprintf("2.%06d", q$Revision: 14285 $ =~ /(\d+)/o);
+$DBI::PurePerl::VERSION = "2.014286";
 
 $DBI::neat_maxlen ||= 400;
 
@@ -120,7 +120,7 @@ use constant IMA_NO_TAINT_IN   	=> 0x0010; #/* don't check for tainted args*/
 use constant IMA_NO_TAINT_OUT   => 0x0020; #/* don't taint results	*/
 use constant IMA_COPY_UP_STMT   => 0x0040; #/* copy sth Statement to dbh */
 use constant IMA_END_WORK	=> 0x0080; #/* set on commit & rollback	*/
-use constant IMA_STUB		=> 0x0100; #/* donothing eg $dbh->connected */
+use constant IMA_STUB		=> 0x0100; #/* do nothing eg $dbh->connected */
 use constant IMA_CLEAR_STMT     => 0x0200; #/* clear Statement before call  */
 use constant IMA_UNRELATED_TO_STMT=> 0x0400; #/* profile as empty Statement   */
 use constant IMA_NOT_FOUND_OKAY	=> 0x0800; #/* not error if not found */
@@ -269,31 +269,31 @@ sub  _install_method {
 
     if (IMA_KEEP_ERR & $bitmask) {
 	push @pre_call_frag, q{
-	    my $keep_error = 1;
+	    my $keep_error = DBI::_err_hash($h);
 	};
     }
     else {
 	my $ke_init = (IMA_KEEP_ERR_SUB & $bitmask)
-		? q{= $h->{dbi_pp_parent}->{dbi_pp_call_depth} }
+		? q{= ($h->{dbi_pp_parent}->{dbi_pp_call_depth} && DBI::_err_hash($h)) }
 		: "";
 	push @pre_call_frag, qq{
 	    my \$keep_error $ke_init;
 	};
-	my $keep_error_code = q{
+	my $clear_error_code = q{
 	    #warn "$method_name cleared err";
 	    $h->{err}    = $DBI::err    = undef;
 	    $h->{errstr} = $DBI::errstr = undef;
 	    $h->{state}  = $DBI::state  = '';
 	};
-	$keep_error_code = q{
+	$clear_error_code = q{
 	    printf $DBI::tfh "    !! %s: %s CLEARED by call to }.$method_name.q{ method\n".
 		    $h->{err}, $h->{err}
 		if defined $h->{err} && $DBI::dbi_debug & 0xF;
-	}. $keep_error_code
+	}. $clear_error_code
 	    if exists $ENV{DBI_TRACE};
 	push @pre_call_frag, ($ke_init)
-		? qq{ unless (\$keep_error) { $keep_error_code }}
-		: $keep_error_code
+		? qq{ unless (\$keep_error) { $clear_error_code }}
+		: $clear_error_code
 	    unless $method_name eq 'set_err';
     }
 
@@ -347,7 +347,11 @@ sub  _install_method {
     } if IMA_IS_FACTORY & $bitmask;
 
     push @post_call_frag, q{
-	$keep_error = 0 if $keep_error && $h->{ErrCount} > $ErrCount;
+        if ($keep_error) {
+            $keep_error = 0
+                if $h->{ErrCount} > $ErrCount
+                or DBI::_err_hash($h) ne $keep_error;
+        }
 
 	$DBI::err    = $h->{err};
 	$DBI::errstr = $h->{errstr};
@@ -524,7 +528,7 @@ sub _setup_handle {
     }
     else {	# setting up a driver handle
         $h_inner->{Warn}		= 1;
-        $h_inner->{PrintWarn}		= $^W;
+        $h_inner->{PrintWarn}		= 1;
         $h_inner->{AutoCommit}		= 1;
         $h_inner->{TraceLevel}		= 0;
         $h_inner->{CompatMode}		= (1==0);
@@ -757,7 +761,7 @@ sub _get_sorted_hash_keys {
             for keys %$hash_ref;
         $num_sort = $sort_guess;
     }
-    
+
     my @keys = keys %$hash_ref;
     no warnings 'numeric';
     my @sorted = ($num_sort)
@@ -766,6 +770,10 @@ sub _get_sorted_hash_keys {
     return \@sorted;
 }
 
+sub _err_hash {
+    return 1 unless defined $_[0]->{err};
+    return "$_[0]->{err} $_[0]->{errstr}"
+}
 
 
 package
@@ -951,7 +959,7 @@ sub take_imp_data {
     my $dbh = shift;
     # A reasonable default implementation based on the one in DBI.xs.
     # Typically a pure-perl driver would have their own take_imp_data method
-    # that would delete all but the essential items in the hash before einding with:
+    # that would delete all but the essential items in the hash before ending with:
     #      return $dbh->SUPER::take_imp_data();
     # Of course it's useless if the driver doesn't also implement support for
     # the dbi_imp_data attribute to the connect() method.
@@ -1132,7 +1140,7 @@ you want to use the PurePerl version.
 
  DBI_PUREPERL == 2 Always use PurePerl
 
-You may set the enviornment variable in your shell (e.g. with
+You may set the environment variable in your shell (e.g. with
 set or setenv or export, etc) or else set it in your script like
 this:
 
